==> yoofans-wechat-service-api-1.0.0.sunyan1-20180123.075237-1-sources.jar: cn/yoofans/wechat/api/dto/AuthorizerPageDto.java <==
package cn.yoofans.wechat.api.dto;

import java.io.Serializable;

/**
 * Created by sunyan on 2018/1/20.
 */
public class AuthorizerPageDto implements Serializable {
    private static final long serialVersionUID = 5560806839985891742L;
    private Long id;
    private String nickName;//公众号名称
    private String headImg; //公众号头像
    private String originId;//公众号原始id
    private Boolean authorized; //是否授权
    private Long subscribeNum = 0L; //关注数
    private Long unsubscribeNum = 0L; //取消关注数

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getHeadImg() {
        return headImg;
    }

    public void setHeadImg(String headImg) {
        this.headImg = headImg;
    }

    public String getOriginId() {
        return originId;
    }

    public void setOriginId(String originId) {
        this.originId = originId;
    }

    public Boolean getAuthorized() {
        return authorized;
    }

    public void setAuthorized(Boolean authorized) {
        this.authorized = authorized;
    }

    public Long getSubscribeNum() {
        return subscribeNum;
    }

    public void setSubscribeNum(Long subscribeNum) {
        this.subscribeNum = subscribeNum;
    }

    public Long getUnsubscribeNum() {
        return unsubscribeNum;
    }

    public void setUnsubscribeNum(Long unsubscribeNum) {
        this.unsubscribeNum = unsubscribeNum;
    }
}

==> yoofans-wechat-service-api-1.0.2.sunyan-20180203.073048-5-sources.jar: cn/yoofans/wechat/api/dto/AuthorizerPageDto.java <==
package cn.yoofans.wechat.api.dto;

import java.io.Serializable;

/**
 * Created by sunyan on 2018/1/20.
 */
public class AuthorizerPageDto implements Serializable {
    private static final long serialVersionUID = 5560806839985891742L;
    private Long id;
    private String appId;
    private String nickName;//公众号名称
    private String headImg; //公众号头像
    private String originId;//公众号原始id
    private Boolean authorized; //是否授权
    private Long subscribeNum = 0L; //关注数
    private Long unsubscribeNum = 0L; //取消关注数

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getHeadImg() {
        return headImg;
    }

    public void setHeadImg(String headImg) {
        this.headImg = headImg;
    }

    public String getOriginId() {
        return originId;
    }

    public void setOriginId(String originId) {
        this.originId = originId;
    }

    public Boolean getAuthorized() {
        return authorized;
    }

    public void setAuthorized(Boolean authorized) {
        this.authorized = authorized;
    }

    public Long getSubscribeNum() {
        return subscribeNum;
    }

    public void setSubscribeNum(Long subscribeNum) {
        this.subscribeNum = subscribeNum;
    }

    public Long getUnsubscribeNum() {
        return unsubscribeNum;
    }

    public void setUnsubscribeNum(Long unsubscribeNum) {
        this.unsubscribeNum = unsubscribeNum;
    }
}
